from rich.console import Console

from .models import ConfigGen

console = Console()


def initialize_project():
    """
    Initializes the project by creating default .env and settings.py files.
    """
    try:
        config_generator = ConfigGen()
        console.print('[bold green]Creating default configuration files...[/bold green]')
        config_generator.create_files_default()
        console.print('\n[bold blue]Configuration files .env and settings.py created successfully![/bold blue]')
    except Exception as e:
        console.print(f'[bold red]An error occurred: {e}[/bold red]')



import typer
from rich.console import Console

from .core import initialize_project

app = typer.Typer()
console = Console()


@app.command()
def init(
    mode: str = typer.Argument('default', help='Modo de execução padrão.'),
    verbose: bool = typer.Option(False, '--verbose', '-v', help='Exibe logs detalhados.'),
):
    """
    Cria variáveis de configuração padrão.
    """
    if mode == 'default':
        initialize_project()
    else:
        console.print(f"[yellow]Mode '{mode}' not recognized. Using 'default'.[/yellow]")
        initialize_project()


@app.command()
def django():
    """
    Estrutura de configurações para o Django
    """
    print('Carregando configurações para o Django...')


@app.command()
def fastapi():
    """
    Estrutura de configurações para o FastAPI
    """
    print('Carregando configurações para o FastAPI...')


def main():
    app()
